@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0035';
+our $VERSION = '0.0036';
 
 use Moo;
 use strictures 2;
@@ -221,7 +221,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0035
+version 0.0036
 
 =head1 SYNOPSIS
 
@@ -336,7 +336,10 @@ Return the parameters of a setting for the given B<id>.
 
 =head2 search_settings
 
-  my $settings = $synth->search_settings(some_setting => $value);
+  my $settings = $synth->search_settings(
+    some_setting    => $valu2,
+    another_setting => $value2,
+  );
 
 Return all the settings given a search query.
 
@@ -350,7 +353,8 @@ Return all the settings for the synth model.
 
   my $models = $synth->recall_models;
 
-Return all the models.
+Return all the know models. This method can be called without having
+specified a synth B<model> in the constructor.
 
 =head2 recall_names
 
@@ -374,11 +378,13 @@ Remove all settings for a given B<name>.
 
   $synth->remove_model;
 
-Remove the database table for the object model.
+Remove the database table for the current object model.
 
 =head1 SEE ALSO
 
-The F<t/01-methods.t> file in this distribution
+The L<Mojolicious::Lite> user interface that automates synthesizer configuration saving and retrieval is F<eg/synth-config-mojo.pl>.
+
+The F<t/01-methods.t> and F<eg/synth-config-cli.pl> files in this distribution
 
 L<Moo>
 
